function renderPieChart( idTarget, series, title, arr_colors )
{
    $( '#' + idTarget ).children( ).remove( );
    var plot3 = $.jqplot( idTarget, [series],
    {
        seriesDefaults :
        {
            renderer : $.jqplot.PieRenderer,
            rendererOptions :
            {
                thickness : 50,
                ringMargin : 10,
                fill : true,
                padding : 10,
                sliceMargin : 3,
                startAngle : 45,
                showDataLabels : true,
                dataLabels : 'percent',
                shadow : false,
            }
        },
        legend :
        {
            show : true,
            location : 'e',
            showSwatch : true
        },
        title : title,
        seriesColors : arr_colors
    } );
}

function openDeviceDialogCharts( serial )
{
    $( '#chartKey' ).val( serial );
    $( '#deviceCharts' ).dialog(
    {
        title : ajaxI18N( 'chartsByDevice' ) + ' ' + serial,
        modal : true,
        width : 1000,
        height : 700
    } ).show( ).tabs( );

    $( ".ui-widget-overlay" ).click( function( )
    {
        $( '#deviceCharts' ).dialog( 'destroy' );
    } );
    createChannelStatusChart( 'deviceChartsHolder', 'serial' );
}

function openLinkDialogCharts( serial, link )
{
    $( '#chartKey' ).val( serial + '.' + link );
    $( '#linkCharts' ).dialog(
    {
        title : ajaxI18N( 'chartsByLink' ) + ' ' + serial + '.' + link,
        modal : true,
        width : 1000,
        height : 700
    } ).show( ).tabs( );

    $( ".ui-widget-overlay" ).click( function( )
    {
        $( '#linkCharts' ).dialog( 'destroy' );
    } );
    createChannelStatusChart( 'linkChartsHolder', 'serial.link' );
}

function openChannelDialogCharts( serial, channel )
{
    $( '#chartKey' ).val( serial + '.' + channel );
    $( '#channelCharts' ).dialog(
    {
        title : ajaxI18N( 'chartsByChannel' ) + ' ' + serial + '.' + channel,
        modal : true,
        width : 1000,
        height : 700
    } ).show( ).tabs( );
    $( ".ui-widget-overlay" ).click( function( )
    {
        $( '#channelCharts' ).dialog( 'destroy' );
    } );
    createCallStatsChart( 'channelChartsHolder', 'serial.channel' );
}

function createChannelStatusChart( target, type )
{
    var params = getArrayParamsToMakeChart( type );
    params['ajaxTo'] = 'getChannelStatusChartData';

    jQuery.kajax(
    {
        url : GLOBALAjaxURL,
        beforeSend : showRefreshingCharts( ),
        complete : hideRefreshingCharts,
        data : params,
        dataType : "json",
        success : function( ret )
        {
            clearCharts( );
            $( '.doubleChart' ).children( ).html( '' ).attr( 'style', '' );
            if( ret.success )
            {
                $( '.noDataChart' ).hide( );
                $( '.chart' ).show( );
                $( '.activeChart' ).removeClass( 'activeChart' );
                $( '#' + target + '>.simpleChart' ).addClass( 'activeChart' );

                var titlechart = $( '#channelsStatusChartTitle' ).val( );
                renderPieChart( target + '>.simpleChart', ret.content, titlechart, ["#DB0000", "#F2682E", "#339966"] );
            }
            else
            {
                $( '.noDataChart' ).text( ret.message ).show( );
                $( '.chart' ).hide( );
            }
        }
    } );
}

function createCallStatsChart( target, type )
{
    clearCharts( );
    var params = getArrayParamsToMakeChart( type );
    params['ajaxTo'] = 'getCallStatusChartData';

    jQuery.kajax(
    {
        url : GLOBALAjaxURL,
        beforeSend : showRefreshingCharts( ),
        complete : hideRefreshingCharts,
        data : params,
        dataType : "json",
        success : function( ret )
        {
            if( ret.success )
            {
                $( '.noDataChart' ).hide( );
                $( '.chart' ).show( );

                $( '.activeChart' ).removeClass( 'activeChart' );
                $( '#' + target + '>.doubleChart>.dbc1' ).addClass( 'activeChart' );
                $( '#' + target + '>.doubleChart>.dbc2' ).addClass( 'activeChart' );

                var titlechart1 = $( '#incOutChartTitle' ).val( );
                var titlechart2 = $( '#statusChartTitle' ).val( );

                renderPieChart( target + '>.doubleChart>.dbc1', ret.content[0], titlechart1, ["#8484F4", "#839557"] );
                if(ret.content[1] !== undefined)
                    renderPieChart( target + '>.doubleChart>.dbc2', ret.content[1], titlechart2, ['#DB0000', "#339966", "#8484F4"] );
            }
            else
            {
                $( '.noDataChart' ).text( ret.message ).show( );
                $( '.chart' ).hide( );
            }
        }
    } );

}

function createFailStatsChart( target, type )
{
    var params = getArrayParamsToMakeChart( type );
    params['ajaxTo'] = 'getFailStatusChartData';

    jQuery.kajax(
    {
        url : GLOBALAjaxURL,
        beforeSend : showRefreshingCharts( ),
        complete : hideRefreshingCharts,
        data : params,
        dataType : "json",
        success : function( ret )
        {
            clearCharts( );
            if( ret.success )
            {
                $( '.noDataChart' ).hide( );
                $( '.chart' ).show( );
                $( '.activeChart' ).removeClass( 'activeChart' );
                $( '#' + target + '>.simpleChart' ).addClass( 'activeChart' );
                var titlechart = $( '#failChartTitle' ).val( );
                renderPieChart( target + '>.simpleChart', ret.content, titlechart, ["#DB0000", "#F2682E", "#339966", "#8484F4", "#839557", "#84CDF4", "#934691", "#2A2C7F", '#8E8E8E'] );
            }
            else
            {
                $( '.noDataChart' ).text( ret.message ).show( );
                $( '.chart' ).hide( );
            }
        }
    } );

}

function getArrayParamsToMakeChart( type )
{
    $key_val = $( '#chartKey' ).val( );
    switch(type)
    {
        case 'serial':
            return array_params =
            {
                serial : $key_val
            };

        case 'serial.link':
            $tmp = $key_val.split( '.' );
            return array_params =
            {
                serial : $tmp[0],
                link : $tmp[1]
            };

        default:
            $tmp = $key_val.split( '.' );
            return array_params =
            {
                serial : $tmp[0],
                channel : $tmp[1]
            };
    }
}

function clearCharts( )
{
    $( '.doubleChart' ).children( ).html( '' ).attr( 'style', '' );
    $( '.simpleChart' ).html( '' ).attr( 'style', '' );
    ;
}

function refreshCharts( )
{
    $( '.ui-tabs-active' ).children( ).click( );
}

function showRefreshingCharts( )
{
    $( '.refreshingCharts' ).show( );
}

function hideRefreshingCharts( )
{
    $( '.refreshingCharts' ).hide( );
}
